import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-a34090ba.js';

class Color {
  constructor(color) {
    // rgb
    this.r = 0;
    this.g = 0;
    this.b = 0;
    // hsl
    this.h = 0;
    this.s = 0;
    this.l = 0;
    // alpha
    this.a = 1;
    // hex
    this.hex = '#000000';
    this.innerParsing = false;
    if (color) {
      this.parse(color);
    }
  }
  toRGBAString() {
    return `rgba(${this.r},${this.g},${this.b},${this.a})`;
  }
  toHSLAString() {
    return `hsla(${this.h}deg,${this.s}%,${this.l}%,${this.a})`;
  }
  toHexAlphaString() {
    return this.hex + Color.to2DigitHex(this.a);
  }
  toRGBString() {
    return `rgb(${this.r},${this.g},${this.b})`;
  }
  toHSLString() {
    return `hsl(${this.h}deg,${this.s}%,${this.l}%)`;
  }
  toHexString() {
    return this.hex;
  }
  getRGBA() {
    return {
      r: this.r,
      g: this.g,
      b: this.b,
      a: this.a,
    };
  }
  getHSLA() {
    return {
      h: this.h,
      s: this.s,
      l: this.l,
      a: this.a,
    };
  }
  getLightness() {
    return this.l;
  }
  isDark(threshold = 50) {
    return this.l <= threshold;
  }
  isLight(threshold = 50) {
    return this.l > threshold;
  }
  static to2DigitHex(value) {
    return ('00' + value.toString(16)).substr(-2);
  }
  fixRGB() {
    const h = (this.h % 360) / 360;
    const s = this.s / 100;
    const l = this.l / 100;
    let r;
    let g;
    let b;
    if (s === 0) {
      r = g = b = l * 2.55;
    }
    else {
      const hue2rgb = (p, q, t) => {
        if (t < 0)
          t += 1;
        if (t > 1)
          t -= 1;
        if (t < 1 / 6)
          return p + (q - p) * 6 * t;
        if (t < 1 / 2)
          return q;
        if (t < 2 / 3)
          return p + (q - p) * (2 / 3 - t) * 6;
        return p;
      };
      const q = l < 0.5 ? l * (1 + s) : l + s - l * s;
      const p = 2 * l - q;
      r = hue2rgb(p, q, h + 1 / 3);
      g = hue2rgb(p, q, h);
      b = hue2rgb(p, q, h - 1 / 3);
    }
    this.r = Math.round(r * 255);
    this.g = Math.round(g * 255);
    this.b = Math.round(b * 255);
  }
  fixHSL() {
    const r = this.r / 255;
    const g = this.g / 255;
    const b = this.b / 255;
    const max = Math.max(r, g, b);
    const min = Math.min(r, g, b);
    let h;
    let s;
    let l = (max + min) / 2;
    if (max === min) {
      h = s = 0; // achromatic
    }
    else {
      const d = max - min;
      s = l > 0.5 ? d / (2 - max - min) : d / (max + min);
      switch (max) {
        case r:
          h = (g - b) / d + (g < b ? 6 : 0);
          break;
        case g:
          h = (b - r) / d + 2;
          break;
        case b:
          h = (r - g) / d + 4;
          break;
      }
      h /= 6;
    }
    this.h = Math.round(h * 360);
    this.s = Math.round(s * 100);
    this.l = Math.round(l * 100);
    return this;
  }
  fixHex() {
    this.hex = `#${Color.to2DigitHex(this.r)}${Color.to2DigitHex(this.g)}${Color.to2DigitHex(this.b)}`;
  }
  static limitRGB(value) {
    return Math.max(0, Math.min(255, value));
  }
  static limitAlpha(value) {
    return Math.max(0, Math.min(1, value));
  }
  static limitPercentage(value) {
    return Math.max(0, Math.min(100, value));
  }
  parse(color) {
    var _a, _b, _c, _d;
    let result;
    if (result = /^\s*#([0-9a-f]{1})([0-9a-f]{1})([0-9a-f]{1})([0-9a-f]{1})?\s*$/i.exec(color)) { // Check if color is in #fff or #ffff pattern
      this.r = Color.limitRGB(parseInt(result[1], 16) * 16);
      this.g = Color.limitRGB(parseInt(result[2], 16) * 16);
      this.b = Color.limitRGB(parseInt(result[3], 16) * 16);
      this.a = Color.limitAlpha(parseInt(((_a = result[4]) !== null && _a !== void 0 ? _a : 'F'), 16) / 15);
      this.fixHSL();
      this.fixHex();
    }
    else if (result = /^\s*#([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})?\s*$/i.exec(color)) { // Check if color is in #ffffff or #ffffffff pattern
      this.r = Color.limitRGB(parseInt(result[1], 16));
      this.g = Color.limitRGB(parseInt(result[2], 16));
      this.b = Color.limitRGB(parseInt(result[3], 16));
      this.a = Color.limitAlpha(parseInt(((_b = result[4]) !== null && _b !== void 0 ? _b : 'FF'), 16) / 255);
      this.fixHSL();
      this.fixHex();
    }
    else if (result = /^\s*rgb\(\s*(\d+)\s*,?\s*(\d+)\s*,?\s*(\d+)\s*(?:,?\s*(\d+)\s*){0,1}\)\s*$/i.exec(color)) { // Check if color is in rgb(0,0,0) or rgba(0,0,0,1) pattern
      this.r = Color.limitRGB(result[1]);
      this.g = Color.limitRGB(result[2]);
      this.b = Color.limitRGB(result[3]);
      this.a = Color.limitAlpha((_c = result[4]) !== null && _c !== void 0 ? _c : 1);
      this.fixHSL();
      this.fixHex();
    }
    else if (result = /^\s*hsl\(\s*(\d+)(deg|rad)\s*,?\s*(\d+)%\s*,?\s*(\d+)%\s*(?:,?\s*(\d+)\s*){0,1}\)\s*$/i.exec(color)) { // Check if color is in hsla() pattern
      this.h = (result[1] * (result[2] === 'rad' ? 180 / Math.PI : 1)) % 360;
      this.s = Color.limitPercentage(result[3]);
      this.l = Color.limitPercentage(result[4]);
      this.a = Color.limitAlpha((_d = result[5]) !== null && _d !== void 0 ? _d : 1);
      this.fixRGB();
      this.fixHex();
    }
    else if (!this.innerParsing) {
      this.innerParsing = true;
      const element = document.createElement('div');
      element.style.setProperty('color', color);
      if (element.style.color) {
        this.parse(window.getComputedStyle(element).color);
      }
      element.remove();
    }
    if (!result) {
      try {
        throw new Error('Could not parse color of value: ' + color);
      }
      catch (error) {
        console.error(error);
      }
    }
    this.innerParsing = false;
    return this;
  }
}

const collapsibleDashboardCss = "*{box-sizing:border-box}.dashboard-wrapper{min-height:100vh;min-height:calc(var(--vh) * 100);display:flex;flex-direction:column;--progression:0;--vh:1vh}.dashboard-container{flex-grow:1;flex-shrink:1;display:flex}.main{flex-grow:1;flex-shrink:1;height:100vh;height:calc(var(--vh) * 100);overflow:auto}.side-panel{width:100vw;max-width:21.875rem;max-height:100vh;max-height:calc(var(--vh) * 100);height:100vh;height:calc(var(--vh) * 100);flex-grow:1;flex-shrink:1;position:sticky;top:0;display:flex;flex-direction:column;}.side-panel .side-panel-header{position:sticky;top:0;bottom:0;left:0;right:0;width:100%;padding:0.5em;background:inherit;z-index:1000;display:flex}.side-panel .side-panel-header .side-panel-header-container{flex-grow:1;flex-shrink:1}.side-panel .side-panel-header .menu-button{padding:0.75rem 1rem;border:0;font-weight:400;text-align:center;white-space:nowrap;vertical-align:middle;margin-bottom:auto;background:none;z-index:100000}.dashboard-wrapper:not(.dragging) .side-panel .side-panel-header .menu-button{transition:transform 0.5s cubic-bezier(0.4, 0, 0.2, 1)}[dir=ltr] .side-panel .side-panel-header .menu-button{transform:translateX(calc(var(--progression) * 125%))}[dir=rtl] .side-panel .side-panel-header .menu-button{transform:translateX(calc(var(--progression) * -125%))}.side-panel .side-panel-header .menu-button svg{height:1.25rem;display:block}.side-panel .side-panel-header .menu-button svg g{transform-origin:center center}.dashboard-wrapper:not(.dragging) .side-panel .side-panel-header .menu-button svg g{transition:fill 0.5s cubic-bezier(0.4, 0, 0.2, 1), filter 0.5s cubic-bezier(0.4, 0, 0.2, 1), transform 0.5s cubic-bezier(0.4, 0, 0.2, 1)}.side-panel .side-panel-header .menu-button svg path{fill:rgb(calc(var(--mobile-nav-color-r) + (var(--color-diff-r) * (1 - var(--progression)))), calc(var(--mobile-nav-color-g) + (var(--color-diff-g) * (1 - var(--progression)))), calc(var(--mobile-nav-color-b) + (var(--color-diff-b) * (1 - var(--progression))))) !important}.side-panel .side-panel-header .menu-button g:first-child{transform:rotate(calc((1 - var(--progression)) * 45deg)) translateY(calc((1 - var(--progression)) * 28%))}.side-panel .side-panel-header .menu-button g:nth-child(2){transform:rotate(calc((1 - var(--progression)) * -45deg))}.side-panel .side-panel-header .menu-button g:last-child{transform:translateY(calc((1 - var(--progression)) * 100%));--opacity:calc((1 - var(--progression))) filter: opacity(var(var(--opacity)))}.side-panel .side-panel-content{overflow-y:auto;flex-grow:1;flex-shrink:1;width:100%}@media screen and (min-width: 62.5rem){.side-panel{will-change:max-width;}.side-panel{transition:max-width 0.5s cubic-bezier(0.4, 0, 0.2, 1)}.side-panel .collapse-panel-button{position:sticky;bottom:0;left:0;right:0;display:flex}.side-panel .collapse-panel-button.light button{background-color:rgba(0, 0, 0, 0.1)}.side-panel .collapse-panel-button.dark button{background-color:rgba(255, 255, 255, 0.1)}.side-panel .collapse-panel-button button{cursor:pointer;flex-grow:1;flex-shrink:1;padding:0.75rem 1rem;border:0;display:flex;font-weight:400;text-align:center;white-space:nowrap;vertical-align:middle;justify-content:flex-end}.side-panel .collapse-panel-button button svg{display:block;height:1.625rem;max-height:1.25rem;margin:0}.side-panel .collapse-panel-button button svg{transition:font-size 0.5s cubic-bezier(0.4, 0, 0.2, 1), transform 0.5s cubic-bezier(0.4, 0, 0.2, 1), max-height 0.5s cubic-bezier(0.4, 0, 0.2, 1), margin-left 0.5s cubic-bezier(0.4, 0, 0.2, 1), margin-right 0.5s cubic-bezier(0.4, 0, 0.2, 1)}[dir=rtl] .side-panel .collapse-panel-button button svg.fa-chevron-left{display:none}[dir=ltr] .side-panel .collapse-panel-button button svg.fa-chevron-right{display:none}.collapse-panel .side-panel{max-width:4.375rem;transition-delay:0.1s;}.collapse-panel .side-panel .collapse-panel-button svg{max-height:1.625rem;margin-left:0.625rem !important;margin-right:0.625rem !important;transform:rotate(180deg)}.side-panel .close-panel-button{display:none}}@media screen and (max-width: 62.499375rem){.side-panel{position:fixed !important;z-index:1051;box-shadow:0 0 1.25rem calc((1 - var(--progression)) * 1.25rem) rgba(0, 0, 0, calc((1 - var(--progression)) * 0.3))}.dashboard-wrapper:not(.dragging) .side-panel{transition:transform 0.5s cubic-bezier(0.4, 0, 0.2, 1), box-shadow 0.5s cubic-bezier(0.4, 0, 0.2, 1)}[dir=rtl] .side-panel{transform:translateX(calc(var(--progression) * 100%))}[dir=ltr] .side-panel{transform:translateX(calc(var(--progression) * -100%));-webkit-transform:translateX(calc(var(--progression) * -100%));-moz-transform:translateX(calc(var(--progression) * -100%));-ms-transform:translateX(calc(var(--progression) * -100%));-o-transform:translateX(calc(var(--progression) * -100%))}.dashboard-wrapper:not(.open){--progression:1}.side-panel .collapse-panel-button{display:none}}@media screen and (min-width: 62.5rem){.mobile-nav,.menu-button{display:none !important}}@media screen and (max-width: 62.499375rem){.mobile-nav{display:block;position:sticky;min-height:3.75rem;margin-bottom:0.25rem;box-shadow:0 0 10px 3px rgba(0, 0, 0, 0.3);display:flex}.mobile-nav .mobile-nav-container{margin:auto;padding:0 0.5rem;flex-grow:1;flex-shrink:1;display:flex;justify-content:flex-end;max-width:90vw}.dashboard-wrapper[dir=ltr] .mobile-nav .mobile-nav-container{padding-left:4rem}.dashboard-wrapper[dir=rtl] .mobile-nav .mobile-nav-container{padding-right:4rem}}";

const CollapsibleDashboard = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.collapseChange = createEvent(this, "collapseChange", 7);
    this.direction = 'ltr';
    this.collapse = false;
    this.open = false;
    this.sidePanelBgColorObject = new Color('#e5e5e5');
    this.sidePanelColorObject = new Color('#232323');
    this.mobileNavBgColorObject = new Color('#232323');
    this.mobileNavColorObject = new Color('#e5e5e5');
  }
  collapseChangeHandler(collapse) {
    this.collapseChange.emit(collapse);
  }
  setCollapse(newVal) {
    this.collapseChangeHandler(newVal);
  }
  componentWillLoad() {
    this.direction = window.getComputedStyle(this.element).direction;
    this.setSidePanelBgColor(this.sidePanelBgColor);
    this.setMobileNavBgColor(this.mobileNavBgColor);
  }
  componentDidRender() {
    var _a, _b;
    this.dashboardWrapper = ((_a = this.element.shadowRoot) !== null && _a !== void 0 ? _a : this.element).querySelector('.dashboard-wrapper');
    this.sidePanel = ((_b = this.element.shadowRoot) !== null && _b !== void 0 ? _b : this.element).querySelector('.side-panel');
    // this.mobileNav = (this.element.shadowRoot ?? this.element).querySelector('.mobile-nav');
    this.updateCssVariables();
    this.windowResize();
  }
  setSidePanelBgColor(newVal) {
    if (newVal) {
      this.sidePanelBgColorObject.parse(newVal);
    }
    this.sidePanelBgColor = this.sidePanelBgColorObject.toRGBString();
    this.updateCssVariables();
  }
  setSidePanelColor(newVal) {
    if (newVal) {
      this.sidePanelColorObject.parse(newVal);
      this.sidePanelColor = this.sidePanelColorObject.toRGBString();
    }
    this.updateCssVariables();
  }
  setMobileNavBgColor(newVal) {
    if (newVal) {
      this.mobileNavBgColorObject.parse(newVal);
    }
    this.mobileNavBgColor = this.mobileNavBgColorObject.toRGBString();
    this.updateCssVariables();
  }
  setMobileNavColor(newVal) {
    if (newVal) {
      this.mobileNavColorObject.parse(newVal);
      this.mobileNavColor = this.mobileNavColorObject.toRGBString();
    }
    this.updateCssVariables();
  }
  updateCssVariables() {
    if (this.dashboardWrapper) {
      const mobileNavColor = new Color(this.getMobileNavColor());
      const mobileNavBg = new Color(this.getMobileNavBgColor());
      const sidePanelColor = new Color(this.getSidePanelColor());
      const sidePanelBg = new Color(this.getSidePanelBgColor());
      const mobileNavColorRGBA = mobileNavColor.getRGBA();
      const mobileNavBgRGBA = mobileNavBg.getRGBA();
      const sidePanelColorRGBA = sidePanelColor.getRGBA();
      const sidePanelBgRGBA = sidePanelBg.getRGBA();
      // const diff: {r?: number; g?: number, b?: number} = {};
      for (const key of ['r', 'g', 'b', 'a']) {
        this.dashboardWrapper.style.setProperty(`--mobile-nav-color-${key}`, mobileNavColorRGBA[key]);
        this.dashboardWrapper.style.setProperty(`--mobile-nav-bg-${key}`, mobileNavBgRGBA[key]);
        this.dashboardWrapper.style.setProperty(`--side-panel-color-${key}`, sidePanelColorRGBA[key]);
        this.dashboardWrapper.style.setProperty(`--side-panel-bg-${key}`, sidePanelBgRGBA[key]);
        this.dashboardWrapper.style.setProperty(`--color-diff-${key}`, (sidePanelColorRGBA[key] - mobileNavColorRGBA[key]).toFixed(0));
      }
    }
  }
  async getSidePanelBgColorPromise() {
    return this.getSidePanelBgColor();
  }
  getSidePanelBgColor() {
    return this.sidePanelBgColor;
  }
  getDefaultSidePanelColor() {
    return this.sidePanelBgColorObject.isDark() ? '#efefef' : '#232323';
  }
  async getSidePanelColorPromise() {
    return this.getSidePanelColor();
  }
  getSidePanelColor() {
    var _a;
    return (_a = this.sidePanelColor) !== null && _a !== void 0 ? _a : this.getDefaultSidePanelColor();
  }
  async getMobileNavBgColorPromise() {
    return this.getMobileNavBgColor();
  }
  getMobileNavBgColor() {
    return this.mobileNavBgColor;
  }
  getDefaultMobileNavColor() {
    return this.mobileNavBgColorObject.isDark() ? '#efefef' : '#232323';
  }
  async getMobileNavColorPromise() {
    return this.getMobileNavColor();
  }
  getMobileNavColor() {
    var _a;
    return (_a = this.mobileNavColor) !== null && _a !== void 0 ? _a : this.getDefaultMobileNavColor();
  }
  touchstart(event) {
    var _a, _b;
    this.touchX = (_a = event.touches[0]) === null || _a === void 0 ? void 0 : _a.clientX;
    this.touchY = (_b = event.touches[0]) === null || _b === void 0 ? void 0 : _b.clientY;
    this.width = this.sidePanel.clientWidth;
    this.factor = (this.direction === 'ltr' ? 1 : -1) / this.width;
    if (this.open) {
      return;
    }
    if ((this.touchX >= 20 && this.direction === 'ltr') || (this.touchX <= this.dashboardWrapper.clientWidth - 20 && this.direction === 'rtl')) {
      this.touchX = Infinity;
    }
  }
  touchmove(event) {
    var _a, _b;
    if (!isFinite(this.touchX)) {
      return;
    }
    this.deltaY = this.touchY - ((_a = event.touches[0]) === null || _a === void 0 ? void 0 : _a.clientY);
    this.deltaX = Math.max(0, Math.min(1, (this.touchX - ((_b = event.touches[0]) === null || _b === void 0 ? void 0 : _b.clientX)) * this.factor + +!this.open));
    if (Math.abs(this.deltaY) > 50) {
      this.dashboardWrapper.classList.remove('dragging');
      this.dashboardWrapper.style.removeProperty('--progression');
      this.touchX = Infinity;
      this.deltaX = Infinity;
    }
    else if (Math.abs(this.deltaX) > 0.05) {
      this.dashboardWrapper.classList.add('dragging');
      this.dashboardWrapper.style.setProperty('--progression', this.deltaX.toString());
      event.preventDefault();
    }
  }
  touchend() {
    this.touchX = Infinity;
    this.dashboardWrapper.classList.remove('dragging');
    this.dashboardWrapper.style.removeProperty('--progression');
    if (isFinite(this.deltaX)) {
      if (Math.abs(this.deltaX) > 0.5 && this.open) {
        this.open = false;
      }
      else if (Math.abs(this.deltaX) < 0.5 && !this.open) {
        this.open = true;
      }
    }
    this.deltaX = Infinity;
  }
  windowResize() {
    var _a;
    (_a = this.dashboardWrapper) === null || _a === void 0 ? void 0 : _a.style.setProperty('--vh', `${window.innerHeight * 0.01}px`);
  }
  watchDir(newVal) {
    this.direction = newVal;
  }
  chevronLeft() {
    return (h("svg", { "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "chevron-left", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 320 512", class: "svg-inline--fa fa-chevron-left fa-w-10 fa-7x" }, h("path", { fill: this.getSidePanelColor(), d: "M34.52 239.03L228.87 44.69c9.37-9.37 24.57-9.37 33.94 0l22.67 22.67c9.36 9.36 9.37 24.52.04 33.9L131.49 256l154.02 154.75c9.34 9.38 9.32 24.54-.04 33.9l-22.67 22.67c-9.37 9.37-24.57 9.37-33.94 0L34.52 272.97c-9.37-9.37-9.37-24.57 0-33.94z", class: "" })));
  }
  chevronRight() {
    return (h("svg", { "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "chevron-right", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 320 512", class: "svg-inline--fa fa-chevron-right fa-w-10 fa-7x" }, h("path", { fill: this.getSidePanelColor(), d: "M285.476 272.971L91.132 467.314c-9.373 9.373-24.569 9.373-33.941 0l-22.667-22.667c-9.357-9.357-9.375-24.522-.04-33.901L188.505 256 34.484 101.255c-9.335-9.379-9.317-24.544.04-33.901l22.667-22.667c9.373-9.373 24.569-9.373 33.941 0L285.475 239.03c9.373 9.372 9.373 24.568.001 33.941z", class: "" })));
  }
  menuIcon() {
    return (h("svg", { "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "minus", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 512 512", class: `svg-inline--fa fa-menu fa-w-14 fa-7x` }, h("g", null, h("path", { fill: this.open ? this.getSidePanelColor() : this.getSidePanelBgColor(), d: "M448,64H64c-17.7,0-32,14.3-32,32v32c0,17.7,14.3,32,32,32h384c17.7,0,32-14.3,32-32V96C480,78.3,465.7,64,448,64z" })), h("g", null, h("path", { fill: this.open ? this.getSidePanelColor() : this.getSidePanelBgColor(), d: "M447.5,208.1h-384c-17.7,0-32,14.3-32,32v32c0,17.7,14.3,32,32,32h384c17.7,0,32-14.3,32-32v-32 C479.5,222.4,465.2,208.1,447.5,208.1z" })), h("g", null, h("path", { fill: this.open ? this.getSidePanelColor() : this.getSidePanelBgColor(), d: "M448,350H64c-17.7,0-32,14.3-32,32v32c0,17.7,14.3,32,32,32h384c17.7,0,32-14.3,32-32v-32C480,364.3,465.7,350,448,350z" }))));
  }
  render() {
    return (h(Host, null, h("div", { class: `dashboard-wrapper ${this.collapse ? ' collapse-panel ' : ''}${this.open ? ' open ' : ''}`, dir: this.direction === 'ltr' ? 'ltr' : 'rtl' }, h("div", { class: "dashboard-container" }, h("nav", { class: `side-panel`, style: { 'background-color': this.getSidePanelBgColor(), 'color': this.getSidePanelColor() } }, h("div", { class: "side-panel-header" }, h("div", { class: "side-panel-header-container" }, h("slot", { name: "side-panel-header" })), h("button", { class: `menu-button ${this.open ? 'open' : ''}`, onClick: () => (this.open = !this.open) }, this.menuIcon())), h("div", { class: "side-panel-content" }, h("slot", { name: "side-panel-content" })), h("div", { class: `collapse-panel-button ${this.sidePanelBgColorObject.isDark() ? 'dark' : 'light'}` }, h("button", { onClick: () => (this.collapse = !this.collapse) }, this.direction === 'ltr' ? this.chevronLeft() : this.chevronRight()))), h("main", { class: "main" }, h("nav", { class: "mobile-nav", style: { 'background-color': this.getMobileNavBgColor(), 'color': this.getMobileNavColor() } }, h("div", { class: "mobile-nav-container" }, h("slot", { name: "mobile-nav" }))), h("slot", null))))));
  }
  get element() { return getElement(this); }
  static get watchers() { return {
    "collapse": ["setCollapse"],
    "sidePanelBgColor": ["setSidePanelBgColor"],
    "sidePanelColor": ["setSidePanelColor"],
    "mobileNavBgColor": ["setMobileNavBgColor"],
    "mobileNavColor": ["setMobileNavColor"],
    "direction": ["watchDir"]
  }; }
};
CollapsibleDashboard.style = collapsibleDashboardCss;

const dashboardNavCss = "@charset \"UTF-8\";:host{display:block}*{box-sizing:border-box}.wrapper{margin:0.25rem;white-space:nowrap;vertical-align:middle;color:inherit;text-decoration:none;display:flex;overflow:hidden}.wrapper{transition:color 0.5s cubic-bezier(0.4, 0, 0.2, 1), background-color 0.5s cubic-bezier(0.4, 0, 0.2, 1)}.wrapper .container{flex:1;vertical-align:middle;white-space:nowrap;color:inherit;display:flex;max-width:100%}.wrapper:hover,.wrapper.active{color:var(--active-color);background-color:var(--passive-color)}.wrapper.active>.container .icon::before{content:\"·\";max-width:0;font-size:4.5rem;display:inline-block;vertical-align:middle;position:relative;left:-0.9rem;right:-0.9rem}.wrapper .icon,.wrapper .text{margin:0.75rem 1.125rem}.wrapper .icon{color:inherit;font-size:1.25rem;line-height:1.25rem;height:1.25rem;max-height:1.25rem;width:1.25rem;max-width:1.25rem;text-align:center}.wrapper .icon .icon-container{display:inline-block;vertical-align:middle}.wrapper .text{color:inherit;flex:1;margin:auto 0.5rem;overflow:hidden;line-height:1.25rem}@media screen and (min-width: 62.5rem){.wrapper .icon{font-size:1.25rem;height:1.625rem;max-height:1.25rem;width:1.625rem;line-height:1.625rem;max-width:1.25rem}.wrapper .icon{transition:font-size 0.5s cubic-bezier(0.4, 0, 0.2, 1), max-width 0.5s cubic-bezier(0.4, 0, 0.2, 1), max-height 0.5s cubic-bezier(0.4, 0, 0.2, 1), line-height 0.5s cubic-bezier(0.4, 0, 0.2, 1), margin-left 0.5s cubic-bezier(0.4, 0, 0.2, 1), margin-right 0.5s cubic-bezier(0.4, 0, 0.2, 1)}.wrapper .text{filter:opacity(1);-webkit-filter:opacity(1)}.wrapper .text{transition:flex 0.5s cubic-bezier(0.4, 0, 0.2, 1), margin-left 0.5s cubic-bezier(0.4, 0, 0.2, 1), margin-right 0.5s cubic-bezier(0.4, 0, 0.2, 1), filter 0.5s cubic-bezier(0.4, 0, 0.2, 1)}.wrapper.collapsed .icon{font-size:1.625rem;max-height:1.625rem;max-width:1.625rem;margin-left:1rem;margin-right:1rem}.wrapper.collapsed .text{margin-left:0;margin-right:0;flex:0;filter:opacity(0);-webkit-filter:opacity(0)}}";

const DashboardNav = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.active = false;
    this.class = '';
    this.collapsed = false;
  }
  watchClass(newVal) {
    this.active = newVal.split(/\s+/).includes('active');
  }
  componentWillLoad() {
    let dashboard = this.element;
    while ((dashboard = dashboard.parentElement)) {
      if (dashboard.tagName.toLowerCase() === 'collapsible-dashboard') {
        break;
      }
    }
    this.dashboard = dashboard;
    if (dashboard) {
      //@ts-ignore
      dashboard === null || dashboard === void 0 ? void 0 : dashboard.getSidePanelColorPromise().then(color => { var _a; return ((_a = this.element.shadowRoot) !== null && _a !== void 0 ? _a : this.element).querySelector('.wrapper').style.setProperty('--passive-color', color); });
      //@ts-ignore
      dashboard === null || dashboard === void 0 ? void 0 : dashboard.getSidePanelBgColorPromise().then(color => { var _a; return ((_a = this.element.shadowRoot) !== null && _a !== void 0 ? _a : this.element).querySelector('.wrapper').style.setProperty('--active-color', color); });
      this.dashboard.addEventListener('collapseChange', (collapse) => {
        this.collapsed = collapse.detail;
      });
      this.collapsed = this.dashboard.collapse;
    }
  }
  componentDidRender() {
    this.watchClass(this.class);
  }
  render() {
    return (h(Host, null, h("a", { href: this.href, class: `wrapper ${this.collapsed ? 'collapsed' : ''} ${this.active ? 'active' : ''}` }, h("div", { class: 'container' }, h("div", { class: 'icon' }, h("div", { class: 'icon-container' }, h("slot", { name: 'icon' }))), h("div", { class: 'text' }, h("slot", null))))));
  }
  get element() { return getElement(this); }
  static get watchers() { return {
    "class": ["watchClass"]
  }; }
};
DashboardNav.style = dashboardNavCss;

export { CollapsibleDashboard as collapsible_dashboard, DashboardNav as dashboard_nav };
